@@ -8,10 +8,18 @@ from pathlib import Path
 
 __DEFAULT_FILE__ = '/root/.github_release_notifier/versions'
 
+
 def version_compare(version1, version2):
     def normalize(v):
-        return [int(x) for x in re.sub(r'(\.0+)*$','', v).split(".")]
-    return cmp(normalize(version1), normalize(version2))
+        return [int(x) for x in re.sub(r'([^\.0-9]+)', '', v).split(".")]
+
+    return (normalize(version1) > normalize(version2)) - (normalize(version1) < normalize(version2))
+
+async def _call_webhook(webhook, json, logger):
+    try:
+        requests.post(webhook, json)
+    except:
+        logger.error("Error occured : %s" % (sys.exc_info()[0]))
 
 def run(file=__DEFAULT_FILE__):
     logging.basicConfig(level=logging.INFO)
@@ -26,11 +34,7 @@ def run(file=__DEFAULT_FILE__):
                 updated[package] = entry['version']
                 for webhook in get(package):
                     logger.info("Hook call : %s / %s" % (webhook, json.dumps(entry)))
-                    try:
-                        requests.post(webhook, data=json.dumps(entry), headers={'Content-Type': 'application/json'})
-                    except:
-                        logger.error("Error occured : %s" % (sys.exc_info()[0]))
-                        pass
+                    _call_webhook(webhook, entry, logger)
     return updated
 
 
